==> hivemind-flask-chatroom-0.0.1.tar.gz: hivemind-flask-chatroom-0.0.1/setup.py <==
from setuptools import setup
import os

BASEDIR = os.path.abspath(os.path.dirname(__file__))

with open(f"{BASEDIR}/README.md", "r") as fh:
    long_desc = fh.read()


def get_version():
    """ Find the version of the package"""
    version_file = os.path.join(BASEDIR, 'hivemind_chatroom', 'version.py')
    major, minor, build, alpha = (None, None, None, None)
    with open(version_file) as f:
        for line in f:
            if 'VERSION_MAJOR' in line:
                major = line.split('=')[1].strip()
            elif 'VERSION_MINOR' in line:
                minor = line.split('=')[1].strip()
            elif 'VERSION_BUILD' in line:
                build = line.split('=')[1].strip()
            elif 'VERSION_ALPHA' in line:
                alpha = line.split('=')[1].strip()

            if ((major and minor and build and alpha) or
                    '# END_VERSION_BLOCK' in line):
                break
    version = f"{major}.{minor}.{build}"
    if int(alpha):
        version += f"a{alpha}"
    return version


def required(requirements_file):
    """ Read requirements file and remove comments and empty lines. """
    with open(os.path.join(BASEDIR, requirements_file), 'r') as f:
        requirements = f.read().splitlines()
        if 'MYCROFT_LOOSE_REQUIREMENTS' in os.environ:
            print('USING LOOSE REQUIREMENTS!')
            requirements = [r.replace('==', '>=').replace('~=', '>=') for r in requirements]
        return [pkg for pkg in requirements
                if pkg.strip() and not pkg.startswith("#")]


setup(
    name='hivemind-flask-chatroom',
    version=get_version(),
    packages=['hivemind_chatroom'],
    url='https://github.com/OpenJarbas/HiveMind-chatroom',
    license='MIT',
    author='jarbasAI',
    author_email='jarbasai@mailfence.com',
    description='Hivemind OVOS Chatroom',
    long_description=long_desc,
    long_description_content_type='text/markdown',
    install_requires=required("requirements.txt"),
    entry_points={
        'console_scripts': [
            'hivemind-flask-chatroom=hivemind_chatroom.__main__:main'
        ]
    }
)

==> hivemind-flask-chatroom-0.1.0a1.tar.gz: hivemind-flask-chatroom-0.1.0a1/setup.py <==
from setuptools import setup
import os

BASEDIR = os.path.abspath(os.path.dirname(__file__))

with open(f"{BASEDIR}/README.md", "r") as fh:
    long_desc = fh.read()


def get_version():
    """ Find the version of the package"""
    version_file = os.path.join(BASEDIR, 'hivemind_chatroom', 'version.py')
    major, minor, build, alpha = (None, None, None, None)
    with open(version_file) as f:
        for line in f:
            if 'VERSION_MAJOR' in line:
                major = line.split('=')[1].strip()
            elif 'VERSION_MINOR' in line:
                minor = line.split('=')[1].strip()
            elif 'VERSION_BUILD' in line:
                build = line.split('=')[1].strip()
            elif 'VERSION_ALPHA' in line:
                alpha = line.split('=')[1].strip()

            if ((major and minor and build and alpha) or
                    '# END_VERSION_BLOCK' in line):
                break
    version = f"{major}.{minor}.{build}"
    if int(alpha):
        version += f"a{alpha}"
    return version


def required(requirements_file):
    """ Read requirements file and remove comments and empty lines. """
    with open(os.path.join(BASEDIR, requirements_file), 'r') as f:
        requirements = f.read().splitlines()
        if 'MYCROFT_LOOSE_REQUIREMENTS' in os.environ:
            print('USING LOOSE REQUIREMENTS!')
            requirements = [r.replace('==', '>=').replace('~=', '>=') for r in requirements]
        return [pkg for pkg in requirements
                if pkg.strip() and not pkg.startswith("#")]


setup(
    name='hivemind-flask-chatroom',
    version=get_version(),
    packages=['hivemind_chatroom'],
    url='https://github.com/JarbasHiveMind/hivemind-flask-chatroom',
    license='Apache2.0',
    author='jarbasAI',
    author_email='jarbasai@mailfence.com',
    description='Hivemind OVOS Chatroom',
    long_description=long_desc,
    long_description_content_type='text/markdown',
    install_requires=required("requirements.txt"),
    entry_points={
        'console_scripts': [
            'hivemind-flask-chatroom=hivemind_chatroom.__main__:main'
        ]
    }
)
